
#############
API Reference
#############

.. currentmodule:: tropycal

.. autosummary::
   :toctree: generated/

   tropycal.tracks
   tropycal.tornado
   tropycal.rain
   tropycal.recon
   tropycal.realtime
   tropycal.ships
   tropycal.utils
   
===============
Keyword Options
===============

Various plotting functions in Tropycal make use of properties to allow the user to customize the plots:

.. list-table:: 
   :widths: 25 75
   :header-rows: 1

   * - Page
     - Description
   * - :doc:`../options/domain`
     - List of available map domains for plotting.
   * - :doc:`../options/map_prop`
     - List of available map customization properties.

* :ref:`modindex`
* :ref:`genindex`